@@ -5,6 +5,7 @@ exceptions.py
 
 import logging
 
+from django.core.paginator import EmptyPage
 from django.db import DatabaseError
 from django.http import Http404
 from django.utils.translation import gettext_lazy as _
@@ -16,6 +17,7 @@ from rest_framework.exceptions import (
     PermissionDenied,
     NotAuthenticated,
     MethodNotAllowed,
+    NotFound, ParseError,
 )
 from rest_framework.views import exception_handler, set_rollback
 
@@ -65,6 +67,15 @@ def exception_handler(exc, context):
     msg = None
     if isinstance(exc, Http404):
         code = ComCodeChoice.API_NOT_FUND
+    elif isinstance(exc, EmptyPage):
+        # 404
+        code = ComCodeChoice.API_NOT_FUND
+    elif isinstance(exc, NotFound):
+        # 404
+        code = ComCodeChoice.API_NOT_FUND
+    elif isinstance(exc, ParseError):
+        # 400
+        code = ComCodeChoice.BAD
     elif isinstance(exc, ValidationError):
         # 400
         code = ComCodeChoice.BAD
